==> walkers-fabric-1.18.2-5.3.3-sources.jar: tocraft/walkers/impl/variant/MushroomCowTypeProvider.java <==
package tocraft.walkers.impl.variant;

import net.minecraft.class_1299;
import net.minecraft.class_1438;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_5250;
import tocraft.craftedcore.patched.TComponent;
import tocraft.walkers.api.variant.TypeProvider;
//#if MC<=1182
//$$ import tocraft.walkers.mixin.accessor.MushroomCowAccessor;
//#endif

public class MushroomCowTypeProvider extends TypeProvider<class_1438> {

    @Override
    public int getVariantData(class_1438 entity) {
        //#if MC>1182
        return entity.getVariant().ordinal();
        //#else
        //$$ return entity.getMushroomType().ordinal();
        //#endif
    }

    @Override
    public class_1438 create(class_1299<class_1438> type, class_1937 level, int data) {
        class_1438 mooshroom = new class_1438(type, level);
        //#if MC>1182
        mooshroom.setVariant(class_1438.class_4053.values()[data]);
        //#else
        //$$ ((MushroomCowAccessor) mooshroom).callSetMushroomType(MushroomCow.MushroomType.values()[data]);
        //#endif
        return mooshroom;
    }

    @Override
    public int getFallbackData() {
        return class_1438.class_4053.field_18109.ordinal();
    }

    @Override
    public int getRange() {
        return class_1438.class_4053.values().length - 1;
    }

    @Override
    public class_2561 modifyText(class_1438 entity, class_5250 text) {
        //#if MC>1182
        String variantName = entity.getVariant().getSerializedName();
        //#else
        //$$ String variantName = entity.getMushroomType().name();
        //#endif
        return TComponent.literal(formatTypePrefix(variantName) + " ").method_10852(text);
    }
}

==> walkers-fabric-1.20.6-5.3-sources.jar: tocraft/walkers/impl/variant/MushroomCowTypeProvider.java <==
package tocraft.walkers.impl.variant;

import net.minecraft.class_1299;
import net.minecraft.class_1438;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_5250;
import tocraft.craftedcore.patched.TComponent;
import tocraft.walkers.api.variant.TypeProvider;
//#if MC<=1182
//$$ import tocraft.walkers.mixin.accessor.MushroomCowAccessor;
//#endif

public class MushroomCowTypeProvider extends TypeProvider<class_1438> {

    @Override
    public int getVariantData(class_1438 entity) {
        //#if MC>1182
        return entity.method_47847().ordinal();
        //#else
        //$$ return entity.getMushroomType().ordinal();
        //#endif
    }

    @Override
    public class_1438 create(class_1299<class_1438> type, class_1937 level, int data) {
        class_1438 mooshroom = new class_1438(type, level);
        //#if MC>1182
        mooshroom.method_47846(class_1438.class_4053.values()[data]);
        //#else
        //$$ ((MushroomCowAccessor) mooshroom).callSetMushroomType(MushroomCow.MushroomType.values()[data]);
        //#endif
        return mooshroom;
    }

    @Override
    public int getFallbackData() {
        return class_1438.class_4053.field_18109.ordinal();
    }

    @Override
    public int getRange() {
        return class_1438.class_4053.values().length - 1;
    }

    @Override
    public class_2561 modifyText(class_1438 entity, class_5250 text) {
        //#if MC>1182
        String variantName = entity.method_47847().method_15434();
        //#else
        //$$ String variantName = entity.getMushroomType().name();
        //#endif
        return TComponent.literal(formatTypePrefix(variantName) + " ").method_10852(text);
    }
}
